import pytest

from packaging_demo.state_info import is_city_capitol_of_state


@pytest.mark.parametrize(
    argnames="city_name, state, is_capitol",
    argvalues=[
        ("Montgomery", "Alabama", True),
        ("Oklahoma City", "Oklahoma", True),
        ("Salem", "Oregon", True),
        ("Salt Lake City", "Alabama", False),
    ],
)
def test_is_city_capitol_of_state__for_correct_city_state_pair(city_name: str, state: str, is_capitol: bool):
    assert is_city_capitol_of_state(city_name=city_name, state=state) == is_capitol



import numpy as np

from packaging_demo.my_folder.my_nested_file import CONSTANT as CONSTANT2
from packaging_demo.my_other_file import CONSTANT

MY_ARRAY = np.array([1, 2, 3])
print(MY_ARRAY)

print(CONSTANT)
print(CONSTANT2)



from setuptools import setup

setup()

"""
Shortcomings of sdist format

1. May make assumptions about customer mcahine:
   e.g. requires "gcc" to run :gcc numpy/*.c"

2. Is slow: setup.py must be executed, compilation may
   be required.

3. Is insecure: setup.py may contain arbitrary code
"""
